Overview — pycollect 0.0.0 documentation

### Navigation

- ☰
- pycollect-0.0.0 »

Fork me on GitHub

# Overview

docs |
tests |
package |

Utility library for collection valid Python files recursively

- Free software: MIT license

## Installation

    pip install pycollect

## Documentation

https://allrod5.github.io/pycollect/

## Development

To run the all tests run:

    make tests

### Navigation

- index
- modules |
- next |
- previous |